Εκθέσεις | OiRA

Θέματα

# Εκθέσεις

Μπορείτε να χρησιμοποιήσετε μια έκθεση για τους ακόλουθους σκοπούς:

- την παροχή αποδεικτικών στοιχείων στις αρμόδιες εποπτικές αρχές,
- τη διαβίβαση πληροφοριών στους ενδιαφερόμενους (εργαζομένους, εκπροσώπους ασφαλείας, εργοδότες, εμπειρογνώμονες στον τομέα της ασφάλειας και τη υγείας, κ.λπ.),
- την παρακολούθηση και την εκτίμηση του κατά πόσον έχουν θεσπιστεί τα αναγκαία μέτρα,
- την καταγραφή τυχόν αναθεωρήσεων σε περίπτωση μεταβολής των συνθηκών (νέα μηχανήματα/νέοι εργαζόμενοι ή ως αποτέλεσμα των πορισμάτων διερευνήσεων ατυχημάτων, κ.λπ.).

Μπορείτε να αποθηκεύσετε την έκθεση στον υπολογιστή σας και να την εκτυπώσετε. Μπορείτε επίσης να την τροποποιήσετε και να προσθέσετε περισσότερες πληροφορίες. Έχετε υπόψη ότι τυχόν αλλαγές σε έκθεση που έχετε μεταφορτώσει ΔΕΝ αποθηκεύονται στο εργαλείο OiRA.

## Επιλογή εκθέσεων

Υπάρχουν διάφορα είδη εκθέσεων που διατίθενται για διάφορους σκοπούς. Η επιλογή των εκθέσεων που είναι διαθέσιμες για συγκεκριμένα εργαλεία εξαρτάται από τις αποφάσεις του εθνικού εταίρου/υπεύθυνου ανάπτυξης του εργαλείου OiRA.

Διαθέσιμες εκθέσεις.

### Πλήρης έκθεση

Μορφότυπος: Word / Office Open XML (.docx). Μπορείτε να την επανεξετάσετε αφού τη μεταφορτώσετε.

Σας παρέχει: όλες τις πληροφορίες και τα στοιχεία που εισαγάγατε μέσω της διαδικασίας εκτίμησης των κινδύνων.

Χρησιμοποιήστε την για: την παροχή στοιχείων σχετικά με την εκτίμηση των κινδύνων στις αρμόδιες εποπτικές αρχές (π.χ. στην επιθεώρηση εργασίας).

### Σχέδιο δράσης

Μορφότυπος: Excel / Office Open XML (.xlsx). Μπορείτε να το επανεξετάσετε αφού το μεταφορτώσετε.

Παρέχει: πληροφορίες για το σύνολο των μέτρων που επιλέξατε να εφαρμόσετε.

Χρησιμοποιήστε το για:

- την ενεργή παρακολούθηση της εφαρμογής των μέτρων που έχετε επιλέξει,
- τη διαχείριση προβλημάτων/κινδύνων στον χώρο εργασίας σας (ειδικά καθήκοντα, εμπειρογνωμοσύνη, αρμοδιότητες, προθεσμίες).

### Επισκόπηση των κινδύνων

Μορφότυπος: Μορφότυπος φορητού εγγράφου (.pdf). Δεν μπορείτε να την επανεξετάσετε αφού την μεταφορτώσετε.

Παρέχει: επισκόπηση των κινδύνων που αναγνωρίστηκαν

Χρησιμοποιήστε το για:

- γρήγορη επισκόπηση της κατάστασης όσον αφορά τους κινδύνους στον χώρο εργασίας σας,
- τη διαβίβαση πληροφοριών στους ενδιαφερόμενους,
- την παρακολούθηση της ορθής αντιμετώπισης των κινδύνων/εφαρμογής των μέτρων.

### Επισκόπηση των μέτρων

Μορφότυπος: Μορφότυπος φορητού εγγράφου (.pdf). Δεν μπορείτε να την επανεξετάσετε αφού την μεταφορτώσετε.

Παρέχει: γρήγορη επισκόπηση των εφαρμοστέων μέτρων.

Χρησιμοποιήστε την για:

- γρήγορη επισκόπηση της κατάστασης όσον αφορά τα μέτρα που έχετε αποφασίσει να εφαρμόσετε,
- τη διαβίβαση πληροφοριών στους ενδιαφερόμενους,
- την παρακολούθηση της ορθής αντιμετώπισης των κινδύνων/εφαρμογής των μέτρων.

Scroll to top Load toolbar…
Back

## 4-reports.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More